@@ -27,11 +27,22 @@ retrieve the primary selection text using GTK 4, even when the main program
 is using GTK 3.
 '''
 from typing import Optional
+from typing import TYPE_CHECKING
 import sys
+import os
+from gi import require_version
 # pylint: disable=wrong-import-position
-import gi # type: ignore
-gi.require_version("Gtk", "4.0")
-from gi.repository import Gtk, Gdk, Gio, GLib # type: ignore
+require_version('GLib', '2.0')
+require_version('Gio', '2.0')
+from gi.repository import Gio, GLib # type: ignore
+os.environ['ITB_GTK_VERSION'] = '4'
+from itb_gtk import Gdk, Gtk  # type: ignore
+if TYPE_CHECKING:
+    # These imports are only for type checkers (mypy). They must not be
+    # executed at runtime because itb_gtk controls the Gtk/Gdk versions.
+    # pylint: disable=reimported
+    from gi.repository import Gtk, Gdk  # type: ignore
+    # pylint: enable=reimported
 # pylint: enable=wrong-import-position
 
 class ClipboardApp(Gtk.Application): # type: ignore[misc]
@@ -39,7 +50,7 @@ class ClipboardApp(Gtk.Application): # type: ignore[misc]
     def __init__(self) -> None:
         super().__init__(application_id="org.freedesktop.ibus.engine.typing_booster.GetSelection")
         self.window: Optional[Gtk.ApplicationWindow] = None
-        self.display: Gdk.Display = Gdk.Display.get_default()
+        self.display: Gdk.Display = Gdk.Display.get_default() # pylint: disable=no-value-for-parameter
 
     def do_activate(self) -> None: # pylint: disable=arguments-differ
         if 'wayland' in self.display.get_name().lower():
@@ -59,10 +70,10 @@ class ClipboardApp(Gtk.Application): # type: ignore[misc]
 
     def try_read_clipboard(self) -> bool:
         '''Method to read the clipboard and print the result'''
-        clipboard: Gdk.Clipboard = self.display.get_primary_clipboard()
+        clipboard: Gdk.Clipboard = self.display.get_primary_clipboard() # pylint: disable=c-extension-no-member
 
         def on_text_received(
-                clipboard: Gdk.Clipboard, result: Gio.AsyncResult) -> None:
+                clipboard: 'Gdk.Clipboard', result: Gio.AsyncResult) -> None:
             try:
                 text: Optional[str] = clipboard.read_text_finish(result)
                 if text is not None:
